@@ -7,6 +7,9 @@
 # does it submit to any jurisdiction.
 #
 
+import os
+
+
 def grib_reader(path):
     from .grib import GRIBReader
     return GRIBReader(path)
@@ -27,6 +30,11 @@ def odb_reader(path):
     return ODBReader(path)
 
 
+def csv_reader(path):
+    from .csv import CSVReader
+    return CSVReader(path)
+
+
 READERS = {
     b'GRIB': grib_reader,
     b'BUFR': bufr_reader,
@@ -34,14 +42,21 @@ READERS = {
     b'CDF\x01': netcdf_reader,
     b'CDF\x02': netcdf_reader,
     b'\xff\xffOD': odb_reader,
+
+    '.csv': csv_reader,
 }
 
 
 def reader(path):
+
+    _, extension = os.path.splitext(path)
+    if extension in READERS:
+        return READERS[extension](path)
+
     with open(path, 'rb') as f:
         header = f.read(4)
 
     if header in READERS:
         return READERS[header](path)
 
-    raise ValueError('Unsupported file {} (header={})'.format(path, header))
+    raise ValueError('Unsupported file {} (header={}, extension={})'.format(path, header, extension))
